@@ -16,11 +16,7 @@
 #include <QMimeDatabase>
 
 MarkdownBrowserExtension::MarkdownBrowserExtension(MarkdownPart* part)
-#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 240, 0)
     : KParts::NavigationExtension(part)
-#else
-    : KParts::BrowserExtension(part)
-#endif
     , m_part(part)
     , m_contextMenuActionCollection(new KActionCollection(this))
 {
@@ -122,10 +118,7 @@ void MarkdownBrowserExtension::requestContextMenu(QPoint globalPos,
     KParts::OpenUrlArguments args;
     args.setMimeType(mimeType);
 
-    KParts::BrowserArguments bargs;
-    bargs.setForcesNewWindow(false);
-
-    Q_EMIT popupMenu(globalPos, emitUrl, static_cast<mode_t>(-1), args, bargs, flags, mapAction);
+    Q_EMIT popupMenu(globalPos, emitUrl, static_cast<mode_t>(-1), args, flags, mapAction);
 }
 
 int MarkdownBrowserExtension::xOffset()
